# 
# Produce csv versions of the data for release
# Outputs:
#  - raw_data.csv: all raw data, as recorded during data entry
#  - cleaned_consolidated_data.csv: a cleaned version, fixing known data entry issues and consolidating timing data for maximum coverage
#  - Incubation.rds / Morbidity.rds: incubation and clinical period data, used by the serial interval shiny app
#  

RemoveWithinSpp <- FALSE  # Within-spp inoculations will be removed below
source('Scripts/Main/PrepareData.R')

library(readr)


## All raw data
raw_data <- readRDS("Data/Internal/raw_data.rds")
write_excel_csv(raw_data, "Data/Internal/raw_data.csv")


## Cleaned data
#   - Reorder columns to a more user-friendly format
#		- Remove unnecessary columns added during processing
AllData <- AllData %>% 
	mutate(InoculatedSex = case_when(.data$InoculatedSex == "M" ~ "male",
																	 .data$InoculatedSex == "F" ~ "female",
																	 TRUE ~ .data$InoculatedSex),
				 InoculatedSex = tolower(.data$InoculatedSex)) %>% 
	
	select(CitationKey, ExperimentID, ResultGroup, AnimalID,
				 SourceSpecies, SourceSubSpecies, SourceKnownHost,
				 InoculatedSpecies, InculatedSubSpecies, InoculatedKnownHost, 
				 InoculatedCommonName, InoculatedAge, InoculatedSex, 
				 InoculumID, InoculumType, PassageHost, PassageNumber, 
				 InoculationRoute_raw = InoculationRoute, InoculationRoute_cat = InoculationZone_Depth, InoculationPropDist,
				 Dose, TitrationMethod, 
				 CauseOfDeath, RabiesConfirmed, ConfirmationMethod, RabiesClinicalDiagnosis, OtherCOD, 
				 
				 ExperimentLength,
				 days_survived_lower = nimLower, days_survived_upper = nimUpper, 
				 incubation_lower = inc_nimLower, incubation_upper = inc_nimUpper, 
				 clinical_lower = morb_nimLower, clinical_upper = morb_nimUpper, 
				
				 VirusInSalivaryGlands, VirusExcreted_FirstDay_Lower, VirusExcreted_FirstDay_Upper, ExcretionConfirmationMethod,
				 SalivaTitre_Max, GlandTitre,
				 
				 DiseaseManifestation, AntibodyResponse, 
				 Inoculum_Notes = Notes, # Notes about the inoculum used
				 Comments,  # General comments / notes about this observation
				 RowID)
				 
write_excel_csv(AllData, "Data/Internal/cleaned_consolidated_data.csv")


## Data for Shiny app
saveRDS(dfIncubation, "Data/Internal/Incubation.rds")
saveRDS(dfMorbidity, "Data/Internal/Morbidity.rds")
