#
## Illustrate the assumed proportional inoculation distances
#

library(tibble)
library(dplyr)
library(tidyr)
library(ggplot2)

PLOT_THEME <- theme_bw() +
	theme(strip.background = element_blank(),
				strip.text = element_text(size = 8),
				axis.title = element_text(size = 8),
				axis.text = element_text(size = 7),
				legend.title = element_text(size = 8),
				legend.text = element_text(size = 7), 
				panel.grid = element_blank())


ZoneDistances <- tribble(
	~zone,       ~proptional_distance, ~equal_spacing,
	"Head\n(IC)",  0,                    0/7,
	"Head\n(IM)",  21/119,               1/7,
	"Head\n(SC)",  28/119,               2/7,
	
	"Neck\n(IM)",  28/119,               2/7, # Assumed same as head (SC)
	"Neck\n(SC)",  35/119,               3/7,
	
	"Torso\n(IM)", 56/119,               4/7,
	"Torso\n(SC)", 63/119,               5/7,
	
	"Limbs\n(IM)", 112/119,              6/7,
	"Limbs\n(SC)", 119/119,              7/7
)


ZoneDistances <- ZoneDistances %>% 
	arrange(equal_spacing) %>% 
	mutate(zone = factor(zone, levels = zone)) %>% 
	gather(key = 'distance', value = 'value', -zone) %>% 
	mutate(distance = factor(distance, levels = c('proptional_distance', 'equal_spacing'),
													 labels = c(proptional_distance = 'Inoculation site distance',
													 					  equal_spacing = 'Equal spacing')))

p <- ggplot(ZoneDistances, aes(x = zone, y = value, colour = distance)) +
	geom_point() +
	geom_line(aes(group = distance)) +
	scale_colour_brewer(palette = 'Set2', direction = -1) +
	labs(x = 'Inoculation route', y = 'Relative distance from brain', colour = NULL) +
	PLOT_THEME


ggsave('Plots/InoculationDistances.pdf', p, width = 5, height = 3)
