

# A lighly modified version off ggtree's gheatmap function, exposing the 'fontface' argument for column names:
gheatmap2 <- function (p, data, offset = 0, width = 1, low = "green", high = "red", 
					color = "white", colnames = TRUE, colnames_position = "bottom", 
					colnames_angle = 0, colnames_level = NULL, colnames_offset_x = 0, 
					colnames_offset_y = 0, font.size = 4, hjust = 0.5, fontface = 'plain') 
{
	colnames_position <- match.arg(colnames_position, c("bottom", "top"))
	variable <- value <- lab <- y <- NULL
	width <- width * (p$data$x %>% range(na.rm = TRUE) %>% diff)/ncol(data)
	isTip <- x <- y <- variable <- value <- from <- to <- NULL
	df <- p$data
	df <- df[df$isTip, ]
	start <- max(df$x, na.rm = TRUE) + offset
	dd <- as.data.frame(data)
	i <- order(df$y)
	i <- i[!is.na(df$y[i])]
	lab <- df$label[i]
	dd <- dd[match(lab, rownames(dd)), , drop = FALSE]
	dd$y <- sort(df$y)
	dd$lab <- lab
	dd <- gather(dd, variable, value, -c(lab, y))
	i <- which(dd$value == "")
	if (length(i) > 0) {
		dd$value[i] <- NA
	}
	if (is.null(colnames_level)) {
		dd$variable <- factor(dd$variable, levels = colnames(data))
	}
	else {
		dd$variable <- factor(dd$variable, levels = colnames_level)
	}
	V2 <- start + as.numeric(dd$variable) * width
	mapping <- data.frame(from = dd$variable, to = V2)
	mapping <- unique(mapping)
	dd$x <- V2
	dd$width <- width
	dd[[".panel"]] <- factor("Tree")
	if (is.null(color)) {
		p2 <- p + geom_tile(data = dd, aes(x, y, fill = value), 
												width = width, inherit.aes = FALSE)
	}
	else {
		p2 <- p + geom_tile(data = dd, aes(x, y, fill = value), 
												width = width, color = color, inherit.aes = FALSE)
	}
	if (is(dd$value, "numeric")) {
		p2 <- p2 + scale_fill_gradient(low = low, high = high, 
																	 na.value = NA)
	}
	else {
		p2 <- p2 + scale_fill_discrete(na.value = NA)
	}
	if (colnames) {
		if (colnames_position == "bottom") {
			y <- 0
		}
		else {
			y <- max(p$data$y) + 1
		}
		mapping$y <- y
		mapping[[".panel"]] <- factor("Tree")
		p2 <- p2 + geom_text(data = mapping, aes(x = to, y = y, 
																						 label = from), size = font.size, inherit.aes = FALSE, 
												 angle = colnames_angle, nudge_x = colnames_offset_x, 
												 nudge_y = colnames_offset_y, hjust = hjust, fontface = fontface)
	}
	p2 <- p2 + theme(legend.position = "right", legend.title = element_blank())
	if (!colnames) {
		p2 <- p2 + scale_y_continuous(expand = c(0, 0))
	}
	attr(p2, "mapping") <- mapping
	return(p2)
}
